===================================
Get Help, Report Bugs or Contribute
===================================

Reporting Bugs and Issues, Getting Help, Providing Feedback
===========================================================

We would love to hear from you!
We are writing Stingray to be useful to you, so if you encounter problems, have questions, would like to request features or just want to chat with us, please don't hesitate to get in touch!

The best and easiest way to get in touch with us regarding bugs and issues is the GitHub `Issues page <https://github.com/StingraySoftware/stingray/issues>`_.
If you're not sure whether what you've encountered is a bug, if you have any questions or need advice getting some of the code to run, or would like to request a feature or suggest additions/changes, you can also contact us via the Slack group or our mailing list.

Please use `this link <https://stingray-slack.herokuapp.com>`_ to join Slack or send `one of us <https://github.com/orgs/StingraySoftware/people>`_ an email to join the mailing list.

Getting Involved with Development
=================================

We encourage you to get involved with Stingray in any way you can!
First, read through the `README <https://github.com/StingraySoftware/stingray/blob/master/README.rst>`_.
Then, fork the `stingray <https://github.com/StingraySoftware/stingray>`_ and `notebooks <https://github.com/StingraySoftware/notebooks>`_ repositories (if you need a primer on GitHub and git version control, `look here <https://www.webpagefx.com/blog/web-design/git-tutorials-beginners/>`_) and work your way through the Jupyter notebook tutorials for the main modules.
Once you've familiarized yourself with the basics of Stingray, go to the `Stingray issues page <https://github.com/StingraySoftware/stingray>`_ and try to tackle one!
Other ways to get involved are outlined on the `project ideas <http://timelabtechnologies.com/ideas.html>`_ page, along with some astrophysical background/motivation.
Finally, you can read `these slides <https://speakerdeck.com/abigailstev/stingray-pyastro16>`_ from an early talk on Stingray at the Python in Astronomy 2016 conference.

For organizing and coordinating the software development, we have a Slack group and a mailing list -- please use `this link <https://stingray-slack.herokuapp.com>`_ for Slack or send `one of us <https://github.com/orgs/StingraySoftware/people>`_ an email to join.
